==> image_overlay-5.x-0.5.tar.gz: image_overlay/js/ShapeTypes.js <==
function ShapeType( num ) {	this.type = num; }
ShapeType = new Object();
ShapeType.RECT = 0;
ShapeType.ARROW = 1;
ShapeType.CIRCLE = 2;
ShapeType.TRIANGLE = 3;
ShapeType.Classes = new Array();
ShapeType.Classes[ShapeType.RECT] = function ( ) { return new Rect(); };
ShapeType.Classes[ShapeType.ARROW] = function ( ) { return new Arrow(); };
ShapeType.Classes[ShapeType.TRIANGLE] = function ( ) { return new Triangle(); };
ShapeType.Names = new Array();
ShapeType.Names[ShapeType.ARROW] = "Arrow"; 
ShapeType.Names[ShapeType.RECT] = "Rectangle";
ShapeType.Names[ShapeType.TRIANGLE] = "Triangle";

ShapeType.GetList = function( ) {
var ans = new Array( );
  for( num in ShapeType.Names ) {
    ans[num] = ShapeType.Names[num];
  }
  return ans;
};

ShapeType.GetPoint = function ( container, add_point ) {
  
  if ( container != false ) {
    return container.GetPoint(1);
  }
  else if (add_point != false) {
    return add_point;
  }
  else {
    return new Point(0,0);
  }
}

function Shape (type, id, color, x_padding, y_padding) {
	this.color = color;	
	this.type = type;
	this.id = id;
	this.x_padding = x_padding;
	this.y_padding = y_padding;
	this.functions = ShapeType.Classes[type]();

	return;
}

Shape.Facing = new Object();
Shape.Facing.NORTH = 0;
Shape.Facing.EAST = 1;
Shape.Facing.SOUTH = 2;
Shape.Facing.WEST = 3;

Shape.prototype.Calculate = function ( canvas_shape, container_shape ) { this.functions.Calculate(canvas_shape, this.x_padding, this.y_padding); };
Shape.prototype.Draw = function ( ) { this.functions.Draw(this.id, this.GetColor());};
Shape.prototype.toJSON = function ( container_rect ) { 
	var name = this.GetName();
	var properties = this.functions.toJSON( container_rect, this.GetColor(), false );
	return { 
		"Type" : name,
		"Properties" : properties
	};
};
Shape.prototype.SetColor = function (  new_color ) { this.color = new_color; };
Shape.prototype.GetColor = function ( ) { return this.color; };
Shape.prototype.GetName = function ( ) { return ShapeType.Names[this.type]; };

/**************************************************************************************
**			Following are the actual shape classes. Note that Rect has special qualities, as it is used for the entire canvas 
**	as well as the div.
**************************************************************************************/


//////////////////////////////// Rect ///////////////////////
function Rect() {
	this.TopLeft  = new Point();
	this.TopRight = new Point();
	this.BottomLeft = new Point();
	this.BottomRight = new Point();
}

Rect.GetBottomSpace = function( ) { return 0; };
Rect.GetRightPadding = function( ){ return 0; };
Rect.prototype.SetPoints = function(left_x, right_x, upper_y, lower_y) {
left_x = parseInt(left_x);
right_x = parseInt(right_x);
upper_y = parseInt(upper_y);
lower_y = parseInt(lower_y);
	this.TopLeft.Set(left_x, upper_y);
	this.TopRight.Set(right_x, upper_y);
	this.BottomLeft.Set(left_x, lower_y);
	this.BottomRight.Set(right_x, lower_y);
};
Rect.prototype.GetLeftX = function() { return this.TopLeft.GetX(); };
Rect.prototype.GetRightX = function() { return this.TopRight.GetX(); };
Rect.prototype.GetTopY = function() { return this.TopLeft.GetY(); };
Rect.prototype.GetBottomY = function() { return this.BottomLeft.GetY(); };
Rect.prototype.GetWidth = function() { return this.GetRightX() - this.GetLeftX(); };
Rect.prototype.GetHeight = function() { return this.GetBottomY() - this.GetTopY(); };
Rect.prototype.GetArea = function() { return this.GetHeight() * this.GetWidth(); };
Rect.prototype.GetPoint = function ( int_which ) { //1 = upperleft, 2 = upper right, 3 = lower left, 4 = lower right
	var ans = 0;
	switch ( int_which ) {
		case 1:
			ans = this.TopLeft;
			break;
		case 2:
			ans = this.TopRight;
			break;
		case 3:
			ans = this.BottomLeft;
			break;
		case 4:
			ans = this.BottomRight;
			break;	
	}
		return ans;
};
Rect.prototype.Calculate = function(canvas, x_padding, y_padding) {
  	var height = canvas.GetHeight() - y_padding - Rect.GetBottomSpace(); 
	if ( height < 0 ) { height *= (-1); }
	
	var y_top = canvas.GetTopY();
	if( y_top < 0 ) { y_top *= (-1);};
	var y_bottom = y_top + height;
	var x_left = canvas.GetLeftX();
	var x_right = canvas.GetRightX() - Rect.GetRightPadding();
	
	this.SetPoints(x_left, x_right, y_top, y_bottom);
};
Rect.prototype.Draw = function(id,color) { 
  var canvas = document.getElementById(id);
  // Make sure we don't execute when canvas isn't supported
  if (canvas.getContext) {
    // use getContext to use the canvas for drawing
    var ctx = canvas.getContext('2d');
				ctx.fillStyle = color;
				ctx.lineWidth = 1;
    // Filled triangle
    ctx.fillRect(this.GetLeftX(), this.GetTopY(), this.GetWidth(), this.GetHeight());
	}
//fillRect(x,y,width,height) : Draws a filled rectangle
};
Rect.prototype.toJSON = function( container, color, add_point) { 
		var starter = ShapeType.GetPoint(container, add_point );

  var newUpperLeft = new Point( 0, 0 );
	var newLowerRight = new Point( 0, 0 );
  
	

	this.TopLeft.Add(add_point, newUpperLeft);
	this.BottomRight.Add(add_point, newLowerRight);
  var points = [
    newUpperLeft.toJSON(), 
    newLowerRight.toJSON() 
  ];

  return {
    "color" : color,
    "rectangle" : points
  };
};


//////////////////////// Triangle //////////////////////////

function Triangle( ) {
	this.points = new Array();
	this.points[0] = new Point();
	this.points[1] = new Point();
	this.points[2] = new Point();
	
}

//Triangle.GetYPadding( base ) { return base
Triangle.prototype.SetPoint = function( int_point_num, int_x, int_y ) {
	this.points[int_point_num].Set(int_x, int_y);
};
Triangle.prototype.Draw = function( id, color ) {
  var canvas = document.getElementById(id);
  
  if (canvas.getContext) {						// Make sure we don't execute when canvas isn't supported
    var ctx = canvas.getContext('2d');
		ctx.lineWidth = 1;
    // Filled triangle
    ctx.beginPath();
    ctx.moveTo(this.points[0].GetX(), this.points[0].GetY());
		var i = 0;
		for ( i = 1; i < 3; i++ ) {
			ctx.lineTo(this.points[i].GetX(), this.points[i].GetY());
		};
		ctx.closePath();
		ctx.fillStyle = color;
    ctx.fill();
  }
};
Triangle.prototype.toPrintableString = function( ) {
	ans = "[";
	var i;
	for ( i = 0; i < 3; i++ ) {
		ans += this.points[i].toPrintableString();
	}
	ans += "]";
	return ans; 
 };
Triangle.prototype.GetPoints = function() {
	return this.points;
};
Triangle.prototype.Calculate = function(canvas, x_padding, y_padding ) {

	var height = canvas.GetTopY() - y_padding;
	var tip_y = canvas.GetBottomY( ) + y_padding;
	var tip_x = canvas.GetLeftX() + ( canvas.GetWidth() / 2 );

	var left = canvas.GetLeftX() + x_padding;
	var right = canvas.GetRightX() - x_padding;
	
	this.SetPoint(0, left, height);
	this.SetPoint(1, right, height);
	this.SetPoint(2, tip_x, tip_y);	
};
Triangle.prototype.toJSON = function( container, color, add_point ) { 

  var tri = this.GetPoints();
	var jsontri = new Array();
	var i;
	var starter = ShapeType.GetPoint(container, add_point );
  
	
	for(i = 0; i < tri.length; i++) {
		tri[i].Add(starter, tri[i]);
		jsontri[i] = tri[i].toJSON();		
	}
	
	var ans = {
		"color" : color,
		"polygon" : jsontri
	};
	return ans;
  }
//////////////////////////  Arrow /////////////////////////

function Arrow ( ) { 
	this.rectanglePart = new Rect();
	this.trianglePart = new Triangle();
}

Arrow.GetXPadding = function() { return 5; };
Arrow.GetRectangleHeightFraction = function( ) { return (7/10); };
Arrow.GetBottomSpace = function() { return 5; };
Arrow.GetTopSpace = function() { return 5; };
Arrow.GetRectPadding = function() { return (Arrow.GetXPadding() + 20); };

//Arrow.prototype.ChangeDirection( int_face ) {}
  
Arrow.prototype.toJSON = function( container, color, add_point ) {
	var starter = ShapeType.GetPoint(container, add_point );
	
	var ans = {
    "Triangle": this.trianglePart.toJSON(false, color, starter),
    "Rectangle": this.rectanglePart.toJSON(false, color, starter)
	};
	return ans;
};
Arrow.prototype.Draw = function(canvas_id, color ) {
	this.rectanglePart.Draw(canvas_id, color);
	this.trianglePart.Draw(canvas_id, color);
};	
Arrow.prototype.Calculate = function ( canvas, x_padding, y_padding ) { 
	this.CalculateRect( canvas, x_padding, y_padding );
	this.CalculateTriangle( canvas, x_padding, y_padding );
};

// these are "private" (pretend)
Arrow.prototype.CalculateRect	= function(canvas, x_padding, y_padding) {
	var height = canvas.GetHeight() - y_padding; 
	height *= Arrow.GetRectangleHeightFraction();
	if ( height < 0 ) { height *= (-1); }
	
	var y_top = Arrow.GetTopSpace() - canvas.GetTopY();
	if( y_top < 0 ) { y_top *= (-1);};
	var y_bottom = y_top + height;
	var x_left = canvas.GetLeftX() + Arrow.GetRectPadding();
	var x_right = canvas.GetRightX() - Arrow.GetRectPadding();
	
	this.rectanglePart.SetPoints(x_left, x_right, y_top, y_bottom);
};
Arrow.prototype.CalculateTriangle = function( canvas, x_padding, y_padding ) {
	var height = canvas.GetHeight() - this.rectanglePart.GetHeight() - y_padding;
	var tip_y = this.rectanglePart.GetBottomY() + height - Arrow.GetBottomSpace();
	var tip_x = canvas.GetLeftX() + ( canvas.GetWidth() / 2 );
	
	var top_inset = Arrow.GetRectangleHeightFraction() / 2 ;
	
	var left = canvas.GetLeftX() + top_inset;
	var right = canvas.GetRightX() - top_inset;
	
	this.trianglePart.SetPoint(0, left, this.rectanglePart.GetBottomY());
	this.trianglePart.SetPoint(1, right, this.rectanglePart.GetBottomY());
	this.trianglePart.SetPoint(2, tip_x, tip_y);	
};
Arrow.prototype.Rotate = function ( num ) {
	var canvas = document.getElementById(this.id);	// Make sure we don't execute when canvas isn't supported
	if (canvas.getContext) {  // use getContext to use the canvas for drawing
	var ctx = canvas.getContext('2d');
		ctx.rotate(num);
	}
};


///////////////////////// Ellipse /////////////////////////
function Ellipse() {
	this.center = new Point();
	this.lineWidth = 2;
	this.radius = 3;
}
Ellipse.prototype.SetCenter = function ( center_x, center_y ) { this.center.Set(center_x, cecnter_y); };
Ellipse.prototype.SetLineWidth = function ( width ) { this.lineWidth = parseInt(width); };
Ellipse.prototype.SetRadius = function ( radius ) { this.radius = radius; };
Ellipse.prototype.Calculate = function ( canvas, x_padding, y_padding ) { 
	var height = canvas.GetHeight() - (y_padding * 2);
	var width = canvas.GetWidth() - (x_padding * 2);
	
	var halfheight = height / 2;
	var halfwidth = width / 2;
	
	this.SetCenter( (x_padding + halfwidth), (y_padding + halfheight) );
	this.SetRadius( min(halfheight, halfwidth) );
	
}
Ellipse.prototype.Draw = function () {
  var canvas = document.getElementById(this.id);
  if (canvas.getContext){
    var ctx = canvas.getContext('2d');
		ctx.lineWidth(this.lineWidth);
		ctx.arc(this.center.GettX(), this.center.GetY(), this.radius, 0, ( Math.PI * 2 ), true);
		ctx.stroke();
  }
};

==> image_overlay-5.x-0.6.tar.gz: image_overlay/js/ShapeTypes.js <==
function ShapeType( num ) {	this.type = num; }
ShapeType = new Object();
ShapeType.RECT = 0;
ShapeType.ARROW = 1;
ShapeType.CIRCLE = 2;
ShapeType.TRIANGLE = 3;
ShapeType.Classes = new Array();
ShapeType.Classes[ShapeType.RECT] = function ( ) { return new Rect(); };
ShapeType.Classes[ShapeType.ARROW] = function ( ) { return new Arrow(); };
ShapeType.Classes[ShapeType.CIRCLE] = function ( ) { return new Circle(); };
ShapeType.Classes[ShapeType.TRIANGLE] = function ( ) { return new Triangle(); };
ShapeType.Names = new Array();
ShapeType.Names[ShapeType.RECT] = "Rectangle";
ShapeType.Names[ShapeType.ARROW] = "Arrow"; 
ShapeType.Names[ShapeType.CIRCLE] = "Circle"; 
ShapeType.Names[ShapeType.TRIANGLE] = "Triangle";

ShapeType.GetHandles = function( num ) {

/*var number = parseInt(num);

  switch(number) {
/*    case ShapeType.CIRCLE:
      return {
        se: '.resizeSE'
      };
      break;
    default:*/
      return {
        e: '.resizeE',
        s: '.resizeS',
        se: '.resizeSE'
      };
    /*  break;
  }*/
};

ShapeType.GetList = function( ) {
var ans = new Array( );
  for( num in ShapeType.Names ) {
    ans[num] = ShapeType.Names[num];
  }
  return ans;
};

ShapeType.GetPoint = function ( container, add_point ) {
  
  if ( container != false ) {
    return container.GetPoint(1);
  }
  else if (add_point != false) {
    return add_point;
  }
  else {
    return new Point(0,0);
  }
}

function Shape (type, id, color, x_padding, y_padding) {
	this.color = color;	
	this.type = type;
	this.id = id;
	this.x_padding = x_padding;
	this.y_padding = y_padding;
	this.functions = ShapeType.Classes[type]();

	return;
}

Shape.Facing = new Object();
Shape.Facing.NORTH = 0;
Shape.Facing.EAST = 1;
Shape.Facing.SOUTH = 2;
Shape.Facing.WEST = 3;

Shape.prototype.Calculate = function ( canvas_shape, container_shape ) { this.functions.Calculate(canvas_shape, this.x_padding, this.y_padding); };
Shape.prototype.Draw = function ( ) { this.functions.Draw(this.id, this.GetColor());};
Shape.prototype.toJSON = function ( container_rect ) { 
	var name = this.GetName();
	var properties = this.functions.toJSON( container_rect, this.GetColor(), false );
	return { 
		"Type" : name,
		"Properties" : properties
	};
};
Shape.prototype.SetColor = function (  new_color ) { this.color = new_color; };
Shape.prototype.GetColor = function ( ) { return this.color; };
Shape.prototype.GetName = function ( ) { return ShapeType.Names[this.type]; };

/**************************************************************************************
**			Following are the actual shape classes. Note that Rect has special qualities, as it is used for the entire canvas 
**	as well as the div.
**************************************************************************************/


//////////////////////////////// Rect ///////////////////////
function Rect() {
	this.TopLeft  = new Point();
	this.TopRight = new Point();
	this.BottomLeft = new Point();
	this.BottomRight = new Point();
}

Rect.GetBottomSpace = function( ) { return 0; };
Rect.GetRightPadding = function( ){ return 0; };
Rect.prototype.SetPoints = function(left_x, right_x, upper_y, lower_y) {
left_x = parseInt(left_x);
right_x = parseInt(right_x);
upper_y = parseInt(upper_y);
lower_y = parseInt(lower_y);
	this.TopLeft.Set(left_x, upper_y);
	this.TopRight.Set(right_x, upper_y);
	this.BottomLeft.Set(left_x, lower_y);
	this.BottomRight.Set(right_x, lower_y);
};
Rect.prototype.GetLeftX = function() { return this.TopLeft.GetX(); };
Rect.prototype.GetRightX = function() { return this.TopRight.GetX(); };
Rect.prototype.GetTopY = function() { return this.TopLeft.GetY(); };
Rect.prototype.GetBottomY = function() { return this.BottomLeft.GetY(); };
Rect.prototype.GetWidth = function() { return this.GetRightX() - this.GetLeftX(); };
Rect.prototype.GetHeight = function() { return this.GetBottomY() - this.GetTopY(); };
Rect.prototype.GetArea = function() { return this.GetHeight() * this.GetWidth(); };
Rect.prototype.GetPoint = function ( int_which ) { //1 = upperleft, 2 = upper right, 3 = lower left, 4 = lower right
	var ans = 0;
	switch ( int_which ) {
		case 1:
			ans = this.TopLeft;
			break;
		case 2:
			ans = this.TopRight;
			break;
		case 3:
			ans = this.BottomLeft;
			break;
		case 4:
			ans = this.BottomRight;
			break;	
	}
		return ans;
};
Rect.prototype.Calculate = function(canvas, x_padding, y_padding) {
  	var height = canvas.GetHeight() - y_padding - Rect.GetBottomSpace(); 
	if ( height < 0 ) { height *= (-1); }
	
	var y_top = canvas.GetTopY();
	if( y_top < 0 ) { y_top *= (-1);};
	var y_bottom = y_top + height;
	var x_left = canvas.GetLeftX();
	var x_right = canvas.GetRightX() - Rect.GetRightPadding();
	
	this.SetPoints(x_left, x_right, y_top, y_bottom);
};
Rect.prototype.Draw = function(id,color) { 
  var canvas = document.getElementById(id);
  // Make sure we don't execute when canvas isn't supported
  if (canvas.getContext) {
    // use getContext to use the canvas for drawing
    var ctx = canvas.getContext('2d');
				ctx.fillStyle = color;
				ctx.lineWidth = 1;
    // Filled triangle
    ctx.fillRect(this.GetLeftX(), this.GetTopY(), this.GetWidth(), this.GetHeight());
	}
//fillRect(x,y,width,height) : Draws a filled rectangle
};
Rect.prototype.toJSON = function( container, color, add_point) { 
		var starter = ShapeType.GetPoint(container, add_point );

  var newUpperLeft = new Point( 0, 0 );
	var newLowerRight = new Point( 0, 0 );
  
	

	this.TopLeft.Add(add_point, newUpperLeft);
	this.BottomRight.Add(add_point, newLowerRight);
  var points = [
    newUpperLeft.toJSON(), 
    newLowerRight.toJSON() 
  ];

  return {
    "color" : color,
    "rectangle" : points
  };
};


//////////////////////// Triangle //////////////////////////

function Triangle( ) {
	this.points = new Array();
	this.points[0] = new Point();
	this.points[1] = new Point();
	this.points[2] = new Point();
	
}

//Triangle.GetYPadding( base ) { return base
Triangle.prototype.SetPoint = function( int_point_num, int_x, int_y ) {
	this.points[int_point_num].Set(int_x, int_y);
};
Triangle.prototype.Draw = function( id, color ) {
  var canvas = document.getElementById(id);
  
  if (canvas.getContext) {						// Make sure we don't execute when canvas isn't supported
    var ctx = canvas.getContext('2d');
		ctx.lineWidth = 1;
    // Filled triangle
    ctx.beginPath();
    ctx.moveTo(this.points[0].GetX(), this.points[0].GetY());
		var i = 0;
		for ( i = 1; i < 3; i++ ) {
			ctx.lineTo(this.points[i].GetX(), this.points[i].GetY());
		};
		ctx.closePath();
		ctx.fillStyle = color;
    ctx.fill();
  }
};
Triangle.prototype.toPrintableString = function( ) {
	ans = "[";
	var i;
	for ( i = 0; i < 3; i++ ) {
		ans += this.points[i].toPrintableString();
	}
	ans += "]";
	return ans; 
 };
Triangle.prototype.GetPoints = function() {
	return this.points;
};
Triangle.prototype.Calculate = function(canvas, x_padding, y_padding ) {

	var height = canvas.GetTopY() - y_padding;
	var tip_y = canvas.GetBottomY( ) + y_padding;
	var tip_x = canvas.GetLeftX() + ( canvas.GetWidth() / 2 );

	var left = canvas.GetLeftX() + x_padding;
	var right = canvas.GetRightX() - x_padding;
	
	this.SetPoint(0, left, height);
	this.SetPoint(1, right, height);
	this.SetPoint(2, tip_x, tip_y);	
};
Triangle.prototype.toJSON = function( container, color, add_point ) { 

  var tri = this.GetPoints();
	var jsontri = new Array();
	var i;
	var starter = ShapeType.GetPoint(container, add_point );
  
	
	for(i = 0; i < tri.length; i++) {
		tri[i].Add(starter, tri[i]);
		jsontri[i] = tri[i].toJSON();		
	}
	
	var ans = {
		"color" : color,
		"polygon" : jsontri
	};
	return ans;
  }
//////////////////////////  Arrow /////////////////////////

function Arrow ( ) { 
	this.rectanglePart = new Rect();
	this.trianglePart = new Triangle();
}

Arrow.GetXPadding = function() { return 5; };
Arrow.GetRectangleHeightFraction = function( ) { return (7/10); };
Arrow.GetBottomSpace = function() { return 5; };
Arrow.GetTopSpace = function() { return 5; };
Arrow.GetRectPadding = function() { return (Arrow.GetXPadding() + 20); };

//Arrow.prototype.ChangeDirection( int_face ) {}
  
Arrow.prototype.toJSON = function( container, color, add_point ) {
	var starter = ShapeType.GetPoint(container, add_point );
	
	var ans = {
    "Triangle": this.trianglePart.toJSON(false, color, starter),
    "Rectangle": this.rectanglePart.toJSON(false, color, starter)
	};
	return ans;
};
Arrow.prototype.Draw = function(canvas_id, color ) {
	this.rectanglePart.Draw(canvas_id, color);
	this.trianglePart.Draw(canvas_id, color);
};	
Arrow.prototype.Calculate = function ( canvas, x_padding, y_padding ) { 
	this.CalculateRect( canvas, x_padding, y_padding );
	this.CalculateTriangle( canvas, x_padding, y_padding );
};

// these are "private" (pretend)
Arrow.prototype.CalculateRect	= function(canvas, x_padding, y_padding) {
	var height = canvas.GetHeight() - y_padding; 
	height *= Arrow.GetRectangleHeightFraction();
	if ( height < 0 ) { height *= (-1); }
	
	var y_top = Arrow.GetTopSpace() - canvas.GetTopY();
	if( y_top < 0 ) { y_top *= (-1);};
	var y_bottom = y_top + height;
	var x_left = canvas.GetLeftX() + Arrow.GetRectPadding();
	var x_right = canvas.GetRightX() - Arrow.GetRectPadding();
	
	this.rectanglePart.SetPoints(x_left, x_right, y_top, y_bottom);
};
Arrow.prototype.CalculateTriangle = function( canvas, x_padding, y_padding ) {
	var height = canvas.GetHeight() - this.rectanglePart.GetHeight() - y_padding;
	var tip_y = this.rectanglePart.GetBottomY() + height - Arrow.GetBottomSpace();
	var tip_x = canvas.GetLeftX() + ( canvas.GetWidth() / 2 );
	
	var top_inset = Arrow.GetRectangleHeightFraction() / 2 ;
	
	var left = canvas.GetLeftX() + top_inset;
	var right = canvas.GetRightX() - top_inset;
	
	this.trianglePart.SetPoint(0, left, this.rectanglePart.GetBottomY());
	this.trianglePart.SetPoint(1, right, this.rectanglePart.GetBottomY());
	this.trianglePart.SetPoint(2, tip_x, tip_y);	
};
Arrow.prototype.Rotate = function ( num ) {
	var canvas = document.getElementById(this.id);	// Make sure we don't execute when canvas isn't supported
	if (canvas.getContext) {  // use getContext to use the canvas for drawing
	var ctx = canvas.getContext('2d');
		ctx.rotate(num);
	}
};


///////////////////////// Circle /////////////////////////
function Circle() {
	this.center = new Point();
	this.lineWidth = 1;  // Because of a bug in GD, this should NOT be changed. See drawing_shapes.inc for details.
	this.radius = 3;
}
Circle.prototype.SetCenter = function ( center_x, center_y ) { this.center.Set(center_x, center_y); };
Circle.prototype.SetLineWidth = function ( width ) { this.lineWidth = findInt(width); };
Circle.prototype.SetRadius = function ( radius ) { this.radius = radius; };
Circle.prototype.Calculate = function ( canvas, x_padding, y_padding ) { 
	var height = canvas.GetHeight() - (y_padding * 2);
	var width = canvas.GetWidth() - (x_padding * 2);
	
	var halfheight = height / 2;
	var halfwidth = width / 2;
	
	this.SetCenter( (x_padding + halfwidth), (y_padding + halfheight) );
	this.SetRadius( min(halfheight, halfwidth) );
}
Circle.prototype.Draw = function (id, color) {
  var canvas = document.getElementById(id);
  if (canvas.getContext){
    var ctx = canvas.getContext('2d');
		ctx.lineWidth = this.lineWidth;
    ctx.strokeStyle = color;
		ctx.arc(this.center.GetX(), this.center.GetY(), this.radius, 0, ( Math.PI * 2 ), true);
		ctx.stroke();
  }
};
Circle.prototype.toJSON = function( container, color, add_point ) { 
	var starter = ShapeType.GetPoint(container, add_point );
  
  var middle = new Point(0,0);
  this.center.Add(starter, middle);
  
	var ans = {
		"color" : color,
		"radius" : this.radius,
    "center" : middle.toJSON(),
    "line" : this.lineWidth,    
	};
	return ans;
  }
///////////////////////// Ellipse /////////////////////////
function Ellipse() {
	this.center = new Point();
	this.lineWidth = 2;
	this.radius = 3;
}
Ellipse.prototype.SetCenter = function ( center_x, center_y ) { this.center.Set(center_x, center_y); };
Ellipse.prototype.SetLineWidth = function ( width ) { this.lineWidth = findInt(width); };
Ellipse.prototype.SetRadius = function ( radius ) { this.radius = radius; };
Ellipse.prototype.Calculate = function ( canvas, x_padding, y_padding ) { 
	var height = canvas.GetHeight() - (y_padding * 2);
	var width = canvas.GetWidth() - (x_padding * 2);
	
	var halfheight = height / 2;
	var halfwidth = width / 2;
	
	this.SetCenter( (x_padding + halfwidth), (y_padding + halfheight) );
	this.SetRadius( min(halfheight, halfwidth) );
}
Ellipse.prototype.Draw = function (id, color) {
  var canvas = document.getElementById(id);
  	var height = canvas.GetHeight() - (y_padding * 2);
	var width = canvas.GetWidth() - (x_padding * 2);
  if (canvas.getContext){
    var ctx = canvas.getContext('2d');
		ctx.lineWidth = this.lineWidth;
    ctx.strokeStyle = color;
		ctx.arc(this.center.GetX(), this.center.GetY(), this.radius, 0, ( Math.PI * 2 ), true);
		ctx.stroke();
    ctx.scale((width/height), (height/width));
  }
};
